@@ -5,12 +5,12 @@ use strict;
 use Carp;
 use Scalar::Util qw( blessed );
 
-our $VERSION = '1.013_03';
+use version; our $VERSION = qv( '1.001' );
 
 use overload (
-  '""'  => \&stringify,
-  '<=>' => \&vcmp,
-  'cmp' => \&vcmp,
+    '""'  => \&stringify,
+    '<=>' => \&vcmp,
+    'cmp' => \&vcmp,
 );
 
 use constant REGEX => qr/ ( (?i: Revision: \s+ ) | v | )
@@ -20,360 +20,356 @@ use constant REGEX => qr/ ( (?i: Revision: \s+ ) | v | )
 use constant MATCH => qr/ ^ ( \s* ) @{[ REGEX ]} ( \s* ) $ /x;
 
 my %NORMAL_FORMAT = (
-  prefix => 'v',
-  printf => ['%d'],
-  extend => '.%d',
-  alpha  => '_%02d',
-  suffix => '',
-  fields => 3,
+    prefix => 'v',
+    printf => ['%d'],
+    extend => '.%d',
+    alpha  => '_%02d',
+    suffix => '',
+    fields => 3,
 );
 
 my %NUMERIC_FORMAT = (
-  prefix => '',
-  printf => [ '%d', '.%03d' ],
-  extend => '%03d',
-  alpha  => '_%02d',
-  suffix => '',
-  fields => 2,
+    prefix => '',
+    printf => [ '%d', '.%03d' ],
+    extend => '%03d',
+    alpha  => '_%02d',
+    suffix => '',
+    fields => 2,
 );
 
 my %COMPONENT_NAME;
 
 BEGIN {
-  %COMPONENT_NAME = (
-    revision   => 0,
-    version    => 1,
-    subversion => 2
-  );
+    %COMPONENT_NAME = (
+        revision   => 0,
+        version    => 1,
+        subversion => 2
+    );
 
-  # Make accessors
-  my @fields = ( keys %COMPONENT_NAME, qw( alpha ) );
+    # Make accessors
+    my @fields = ( keys %COMPONENT_NAME, qw( alpha ) );
 
-  no strict 'refs';
+    no strict 'refs';
 
-  for my $field ( @fields ) {
-    *$field = sub {
-      my $self = shift;
-      return $self->component( $field, @_ );
-    };
+    for my $field ( @fields ) {
+        *$field = sub {
+            my $self = shift;
+            return $self->component( $field, @_ );
+        };
 
-    my $inc_func = "inc_$field";
-    *$inc_func = sub {
-      my $self = shift;
-      return $self->increment( $field );
-    };
-  }
+        my $inc_func = "inc_$field";
+        *$inc_func = sub {
+            my $self = shift;
+            return $self->increment( $field );
+        };
+    }
 }
 
 sub new {
-  my $class = shift;
-  my $self
-   = bless {}, ref $class
-   || $class
-   || croak "new must be called as a class or object method";
+    my $class = shift;
+    my $self = bless {}, ref $class
+      || $class
+      || croak "new must be called as a class or object method";
 
-  $self->{version} = [0];
+    $self->{version} = [0];
 
-  $self->_parse( @_ ) if @_;
+    $self->_parse( @_ ) if @_;
 
-  return $self;
+    return $self;
 }
 
 sub _resolve_component_name {
-  my $self = shift;
-  my $name = shift;
+    my $self = shift;
+    my $name = shift;
 
-  if ( $name =~ /^-?\d+$/ ) {
-    # Allow negative subscripts
-    $name += $self->components if $name < 0;
-    return $name;
-  }
+    return $name if $name =~ m{ ^ -? \d+ $ }x;
 
-  croak "Unknown component name: $name"
-   unless exists $COMPONENT_NAME{ lc( $name ) };
+    croak "Unknown component name: $name"
+      unless exists $COMPONENT_NAME{ lc( $name ) };
 
-  return $COMPONENT_NAME{ lc( $name ) };
+    return $COMPONENT_NAME{ lc( $name ) };
 }
 
 sub _guess_num_format {
-  my $self = shift;
-  my $num  = shift;
+    my $self = shift;
+    my $num  = shift;
 
-  if ( $num =~ m{ ^ 0 \d }x ) {
-    return '%0' . length( $num ) . 'd';
-  }
+    if ( $num =~ m{ ^ 0 \d }x ) {
+        return '%0' . length( $num ) . 'd';
+    }
 
-  return '%d';
+    return '%d';
 }
 
 sub _parse {
-  my $self = shift;
+    my $self = shift;
 
-  # Check for vstring before anything else happens
-  if ( $] >= 5.008_001 && Scalar::Util::isvstring $_[0] ) {
-    $self->{format} = {%NORMAL_FORMAT};
-    my @parts = map { ord } split //, shift;
-    $self->{version} = \@parts;
-    return;
-  }
+    # Check for vstring before anything else happens
+    if ( $] >= 5.008_001 && Scalar::Util::isvstring $_[0] ) {
+        $self->{format} = {%NORMAL_FORMAT};
+        my @parts = map { ord } split //, shift;
+        $self->{version} = \@parts;
+        return;
+    }
 
-  my $version = join( ' ', map { "$_" } @_ );
+    my $version = join( ' ', map { "$_" } @_ );
 
-  croak "Illegal version string: $version"
-   unless $version =~ MATCH;
+    croak "Illegal version string: $version"
+      unless $version =~ MATCH;
 
-  my $format = { fields => 1 };
-  my ( $pad, $pfx, $ver, $alp, $sfx ) = ( $1, $2, $3, $4, $5 );
+    my $format = { fields => 1 };
+    my ( $pad, $pfx, $ver, $alp, $sfx ) = ( $1, $2, $3, $4, $5 );
 
-  # Decode version into format
-  $format->{prefix} = $pad . $pfx;
-  $format->{suffix} = $sfx;
+    # Decode version into format
+    $format->{prefix} = $pad . $pfx;
+    $format->{suffix} = $sfx;
 
-  my @parts = split( /[.]/, $ver );
-  my @ver = ( shift( @parts ) + 0 );
+    my @parts = split( /[.]/, $ver );
+    my @ver = ( shift( @parts ) + 0 );
 
-  my @fmt = ( $self->_guess_num_format( $ver[0] ) );
+    my @fmt = ( $self->_guess_num_format( $ver[0] ) );
 
-  if ( @parts == 1 && length( $parts[0] ) >= 3 ) {
+    if ( @parts == 1 && length( $parts[0] ) >= 3 ) {
 
-    my $threes = pop @parts;
-    my @cluster = ( $threes =~ /(\d{1,3})/g );
+        my $threes = pop @parts;
+        my @cluster = ( $threes =~ /(\d{1,3})/g );
 
-    # warn "# $threes <", join( '>, <', @cluster ), ">\n";
-    push @fmt, map { $self->_guess_num_format( $_ ) } @cluster;
-    $fmt[1] = '.' . $fmt[1];
-    $format->{extend} = '%03d';
+        # warn "# $threes <", join( '>, <', @cluster ), ">\n";
+        push @fmt, map { $self->_guess_num_format( $_ ) } @cluster;
+        $fmt[1] = '.' . $fmt[1];
+        $format->{extend} = '%03d';
 
-    push @parts, map { 0 + $_ } @cluster;
-  }
-  else {
-
-    # Parts with leading zeros
-    my @lz = grep { m{ ^ 0 \d }x } @parts;
-
-    # Work out how many different lengths we have
-    my %le = map { length( $_ ) => 1 } @parts;
-
-    if ( @lz && keys %le == 1 ) {
-      push @fmt,
-       ( '.' . $self->_guess_num_format( shift @lz ) ) x @parts;
+        push @parts, map { 0 + $_ } @cluster;
     }
     else {
-      push @fmt, map { '.' . $self->_guess_num_format( $_ ) } @parts;
+
+        # Parts with leading zeros
+        my @lz = grep { m{ ^ 0 \d }x } @parts;
+
+        # Work out how many different lengths we have
+        my %le = map { length( $_ ) => 1 } @parts;
+
+        if ( @lz && keys %le == 1 ) {
+            push @fmt, ( '.' . $self->_guess_num_format( shift @lz ) ) x @parts;
+        }
+        else {
+            push @fmt, map { '.' . $self->_guess_num_format( $_ ) } @parts;
+        }
+
+        $format->{extend} = ( @parts ? '' : '.' ) . $fmt[-1];
     }
 
-    $format->{extend} = ( @parts ? '' : '.' ) . $fmt[-1];
-  }
+    $format->{printf} = \@fmt;
 
-  $format->{printf} = \@fmt;
+    if ( length( $alp ) ) {
+        die "Badly formatted alpha got through"
+          unless $alp =~ m{ _ (\d+) }x;
 
-  if ( length( $alp ) ) {
-    die "Badly formatted alpha got through"
-     unless $alp =~ m{ _ (\d+) }x;
+        my $alpha = $1;
 
-    my $alpha = $1;
+        $self->{alpha}   = $alpha + 0;
+        $format->{alpha} = '_' . $self->_guess_num_format( $alpha );
+    }
+    else {
+        $format->{alpha} = $NORMAL_FORMAT{alpha};
+    }
 
-    $self->{alpha}   = $alpha + 0;
-    $format->{alpha} = '_' . $self->_guess_num_format( $alpha );
-  }
-  else {
-    $format->{alpha} = $NORMAL_FORMAT{alpha};
-  }
+    $self->{format} = $format;
 
-  $self->{format} = $format;
+    push @ver, map { $_ + 0 } @parts;
 
-  push @ver, map { $_ + 0 } @parts;
+    if ( grep { $_ > 999 } @ver ) {
+        carp "Version has component > 999: $version";
+    }
 
-  $self->{version} = \@ver;
+    $self->{version} = \@ver;
 
-  return;
+    return;
 }
 
 sub _format {
-  my $self   = shift;
-  my $format = shift;
+    my $self   = shift;
+    my $format = shift;
 
-  my @result = ();
+    my @result = ();
 
-  my @parts = @{ $self->{version} };
-  my @fmt   = @{ $format->{printf} };
+    my @parts = @{ $self->{version} };
+    my @fmt   = @{ $format->{printf} };
 
-  push @parts, 0 while @parts < $format->{fields};
+    push @parts, 0 while @parts < $format->{fields};
 
-  # Adjust the format to be the same length as the number of fields
-  pop @fmt while @fmt > @parts;
-  push @fmt, $format->{extend} while @parts > @fmt;
+    # Adjust the format to be the same length as the number of fields
+    pop @fmt while @fmt > @parts;
+    push @fmt, $format->{extend} while @parts > @fmt;
 
-  my $version
-   = ( $format->{prefix} )
-   . sprintf( join( '', @fmt ), @parts )
-   . ( $format->{suffix} );
+    my $version
+      = ( $format->{prefix} )
+      . sprintf( join( '', @fmt ), @parts )
+      . ( $format->{suffix} );
 
-  $version .= sprintf( $format->{alpha}, $self->{alpha} )
-   if defined $self->{alpha};
+    $version .= sprintf( $format->{alpha}, $self->{alpha} )
+      if defined $self->{alpha};
 
-  push @result, $version;
+    push @result, $version;
 
-  return join( ' ', @result );
+    return join( ' ', @result );
 }
 
 sub stringify {
-  my $self = shift;
-  return $self->_format( $self->{format} || \%NORMAL_FORMAT );
+    my $self = shift;
+    return $self->_format( $self->{format} || \%NORMAL_FORMAT );
 }
 
 sub normal {
-  return shift->_format( \%NORMAL_FORMAT );
+    return shift->_format( \%NORMAL_FORMAT );
 }
 
 sub numify {
-  return shift->_format( \%NUMERIC_FORMAT );
+    return shift->_format( \%NUMERIC_FORMAT );
 }
 
 sub is_alpha {
-  my $self = shift;
-  return exists $self->{alpha};
+    my $self = shift;
+    return exists $self->{alpha};
 }
 
 sub vcmp {
-  my ( $self, $other, $rev ) = @_;
+    my ( $self, $other, $rev ) = @_;
 
-  # Promote to object
-  $other = __PACKAGE__->new( $other ) unless ref $other;
+    # Promote to object
+    $other = __PACKAGE__->new( $other ) unless ref $other;
 
-  croak "Can't compare with $other"
-   unless blessed $other && $other->isa( __PACKAGE__ );
+    croak "Can't compare with $other"
+      unless blessed $other && $other->isa( __PACKAGE__ );
 
-  return $other->vcmp( $self, 0 ) if $rev;
+    return $other->vcmp( $self, 0 ) if $rev;
 
-  my @this = @{ $self->{version} };
-  my @that = @{ $other->{version} };
+    my @this = @{ $self->{version} };
+    my @that = @{ $other->{version} };
 
-  push @this, 0 while @this < @that;
-  push @that, 0 while @that < @this;
+    push @this, 0 while @this < @that;
+    push @that, 0 while @that < @this;
 
-  while ( @this ) {
-    if ( my $cmp = ( shift( @this ) <=> shift( @that ) ) ) {
-      return $cmp;
+    while ( @this ) {
+        if ( my $cmp = ( shift( @this ) <=> shift( @that ) ) ) {
+            return $cmp;
+        }
     }
-  }
 
-  return ( $self->{alpha} || 0 ) <=> ( $other->{alpha} || 0 );
+    return ( $self->{alpha} || 0 ) <=> ( $other->{alpha} || 0 );
 }
 
 sub components {
-  my $self = shift;
+    my $self = shift;
 
-  if ( @_ ) {
-    my $fields = shift;
+    if ( @_ ) {
+        my $fields = shift;
 
-    if ( ref $fields eq 'ARRAY' ) {
-      $self->{version} = [@$fields];
+        if ( ref $fields eq 'ARRAY' ) {
+            $self->{version} = [@$fields];
+        }
+        else {
+            croak "Can't set the number of components to 0"
+              unless $fields;
+
+            # Adjust the number of fields
+            pop @{ $self->{version} }, while @{ $self->{version} } > $fields;
+            push @{ $self->{version} }, 0,
+              while @{ $self->{version} } < $fields;
+        }
     }
     else {
-      croak "Can't set the number of components to 0"
-       unless $fields;
-
-      # Adjust the number of fields
-      pop @{ $self->{version} }, while @{ $self->{version} } > $fields;
-      push @{ $self->{version} }, 0,
-       while @{ $self->{version} } < $fields;
+        return @{ $self->{version} };
     }
-  }
-  else {
-    return @{ $self->{version} };
-  }
 }
 
 sub component {
-  my $self  = shift;
-  my $field = shift;
+    my $self  = shift;
+    my $field = shift;
 
-  defined $field or croak "You must specify a component number";
+    defined $field or croak "You must specify a component number";
 
-  if ( lc( $field ) eq 'alpha' ) {
-    if ( @_ ) {
-      my $alpha = shift;
-      if ( $alpha ) {
-        $self->{alpha} = $alpha;
-      }
-      else {
-        delete $self->{alpha};
-      }
+    if ( lc( $field ) eq 'alpha' ) {
+        if ( @_ ) {
+            my $alpha = shift;
+            if ( $alpha ) {
+                $self->{alpha} = $alpha;
+            }
+            else {
+                delete $self->{alpha};
+            }
+        }
+        else {
+            return $self->{alpha} || 0;
+        }
     }
     else {
-      return $self->{alpha} || 0;
-    }
-  }
-  else {
-    $field = $self->_resolve_component_name( $field );
-    my $fields = $self->components;
+        $field = $self->_resolve_component_name( $field );
+        my $fields = $self->components;
 
-    if ( @_ ) {
-      if ( $field >= $fields ) {
+        if ( @_ ) {
+            if ( $field >= $fields ) {
 
-        # Extend array if necessary
-        $self->components( $field + 1 );
-      }
+                # Extend array if necessary
+                $self->components( $field + 1 );
+            }
 
-      $self->{version}->[$field] = shift;
+            $self->{version}->[$field] = shift;
+        }
+        else {
+            return unless $field >= 0 && $field < $fields;
+            return $self->{version}->[$field];
+        }
     }
-    else {
-      return unless $field >= 0 && $field < $fields;
-      return $self->{version}->[$field];
-    }
-  }
 }
 
 sub increment {
-  my $self   = shift;
-  my $field  = shift;
-  my $fields = $self->components;
+    my $self   = shift;
+    my $field  = shift;
+    my $fields = $self->components;
 
-  if ( lc( $field ) eq 'alpha' ) {
-    $self->alpha( $self->alpha + 1 );
-  }
-  else {
-    $field = $self->_resolve_component_name( $field );
+    if ( lc( $field ) eq 'alpha' ) {
+        $self->alpha( $self->alpha + 1 );
+    }
+    else {
+        $field = $self->_resolve_component_name( $field );
 
-    croak "Component $field is out of range 0..", $fields - 1
-     if $field < 0 || $field >= $fields;
+        croak "Component $field is out of range 0..", $fields - 1
+          if $field < 0 || $field >= $fields;
 
-    # Increment the field
-    $self->component( $field, $self->component( $field ) + 1 );
+        # Increment the field
+        $self->component( $field, $self->component( $field ) + 1 );
 
-    # Zero out any following fields
-    while ( ++$field < $fields ) {
-      $self->component( $field, 0 );
+        # Zero out any following fields
+        while ( ++$field < $fields ) {
+            $self->component( $field, 0 );
+        }
+        $self->alpha( 0 );
     }
-    $self->alpha( 0 );
-  }
 }
 
 sub set {
-  my $self  = shift;
-  my $other = shift;
+    my $self  = shift;
+    my $other = shift;
 
-  $other = __PACKAGE__->new( $other ) unless ref $other;
+    $other = __PACKAGE__->new( $other ) unless ref $other;
 
-  my @comp = $other->components;
+    my @comp = $other->components;
 
-  $self->components( \@comp );
-  $self->alpha( $other->alpha );
+    $self->components( \@comp );
+    $self->alpha( $other->alpha );
 }
 
 1;
 __END__
 
-=encoding utf8
-
 =head1 NAME
 
 Perl::Version - Parse and manipulate Perl version strings
 
 =head1 VERSION
 
-This document describes Perl::Version version 1.013_03
+This document describes Perl::Version version 1.001
 
 =head1 SYNOPSIS
 
@@ -473,7 +469,7 @@ component? Perl::Version will assume that it is:
     my $version = Perl::Version->new( '1.10.03' );
     $version->inc_revision;
     print "$version\n";
-
+    
 will print
 
     2.00.00
@@ -489,7 +485,7 @@ the same length when stringifying the version.
 
 =head2 Version Formats
 
-Perl::Version supports a few different version string formats.
+Perl::Version supports a few different version string formats. 
 
 =over
 
@@ -522,7 +518,7 @@ Versions with a leading 'v'.
 
 Fielded numeric versions. You'll likely have seen this in relation to
 versions of Perl itself. If a version string has a single decimal point
-and the part after the point is three more more digits long, components
+and the part after the point is three more more digits long components
 are extracted from each group of three digits in the fractional part.
 
 For example
@@ -545,7 +541,7 @@ Perl::Version will successfully parse vstrings
 
     my $version = Perl::Version->new( v1.2 );
     print "$version\n";
-
+    
 prints
 
     v1.2
@@ -586,11 +582,11 @@ internal format. This means that
 
     # Numeric version
     print Perl::Version->new( 1.001_001 )->stringify;
-
+    
 prints
 
     1.001001
-
+    
 but
 
     # String version
@@ -599,7 +595,7 @@ but
 prints
 
     1.001_001
-
+    
 as expected.
 
 In general you should probably avoid versions expressed either as
@@ -634,7 +630,7 @@ the first three components are named 'revision', 'version' and
 
     $ perl -V
     Summary of my perl5 (revision 5 version 8 subversion 6) configuration:
-
+    
     (etc)
 
 Perl::Version follows that convention. Any component may be accessed by
@@ -647,11 +643,11 @@ L<version> and L<subversion>.
 is the same as
 
     $version->inc_revision;
-
+    
 and
 
     my $subv = $version->subversion;
-
+    
 is the same as
 
     my $subv = $version->component( 2 );
@@ -733,10 +729,10 @@ Set or get one of the components of a version.
 
     # Set the subversion
     $version->component( 2, 17 );
-
+    
     # Get the revision
     my $rev = $version->component( 0 );
-
+    
 Instead of a component number you may pass a name: 'revision',
 'version', 'subversion' or 'alpha':
 
@@ -748,13 +744,13 @@ Get or set all of the components of a version.
 
     # Set the number of components
     $version->components( 4 );
-
+    
     # Get the number of components
     my $parts = $version->components;
-
+    
     # Get the individual components as an array
     my @parts = $version->components;
-
+    
     # Set the components from an array
     $version->components( [ 5, 9, 2 ] );
 
@@ -778,7 +774,7 @@ Get or set the alpha component of a version. Returns 0 for versions with no alph
 
     # Set alpha
     $version->alpha( 12 );
-
+    
     # Get alpha
     my $alp = $version->alpha;
 
@@ -812,7 +808,7 @@ Increment a component of a version.
     my $version = Perl::Version->new( '3.1.4' );
     $version->increment( 1 );
     print "$version\n";
-
+    
 prints
 
     3.2.0
@@ -852,7 +848,7 @@ Return a normalised representation of a version.
 
     my $version = Perl::Version->new( '5.008007_01' );
     print $version->normal, "\n";
-
+    
 prints
 
     v5.8.7_001
@@ -907,7 +903,7 @@ depending on their ordering. Comparisons are semantically correct so that
     my $v2 = Perl::Version->new( '1.1.3' );
 
     print ($v1->vcmp( $v2 ) > 0 ? 'yes' : 'no'), "\n";
-
+    
 prints
 
     yes
@@ -921,7 +917,7 @@ prints
 =item C<< <=> >> and C<< cmp >>
 
 The C<< <=> >> and C<< cmp >> operators are overloaded (by the L<vcmp>
-method) so that comparisons between versions work as expected. This
+method) so that comparisions between versions work as expected. This
 means that the other numeric and string comparison operators also work
 as expected.
 
@@ -955,7 +951,7 @@ body of the version and any alpha suffix respectively.
     my $version = 'v1.2.3.4_5';
     my ($prefix, $main, $suffix) = ($version =~ Perl::Version::REGEX);
     print "$prefix\n$main\n$suffix\n";
-
+    
 prints
 
     v
@@ -970,10 +966,10 @@ part, the main body of the version, any alpha suffix and any
 trailing spaces respectively.
 
     my $version = '  v1.2.3.4_5  ';
-    my ($before, $prefix, $main, $suffix, $after)
+    my ($before, $prefix, $main, $suffix, $after) 
                  = ($version =~ Perl::Version::MATCH);
     print "|$before|$prefix|$main|$suffix|$after|\n";
-
+    
 prints
 
     | |v|1.2.3.4|_5| |
@@ -1000,11 +996,11 @@ version. Valid versions match this regex:
 C<new> can't be called as a normal subroutine. Use
 
     $version_object->new( '1.2.3' );
-
+    
 or
 
     Perl::Version->new( '1.2.3' );
-
+    
 instead of
 
     Perl::Version::new( '1.2.3' );
@@ -1044,6 +1040,28 @@ accessors.
 
 =back
 
+=head2 Warnings
+
+=over
+
+=item C<< Decimal part not a multiple of three digits: %s >>
+
+When Perl::Version sees a version number like
+
+    1.002003
+
+it splits the tail of the version so that each group of three digits
+specifies the value of a component. If you pass a version string with,
+say, five digits after the decimal point you'll see this warning.
+
+=item C<< Version has component > 999: %s >>
+
+You passed a version like this:
+
+    1.1000.0
+
+=back
+
 =head1 CONFIGURATION AND ENVIRONMENT
 
 Perl::Version requires no configuration files or environment variables.
@@ -1058,6 +1076,8 @@ None reported.
 
 =head1 BUGS AND LIMITATIONS
 
+No bugs have been reported.
+
 Please report any bugs or feature requests to
 C<bug-perl-version@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
@@ -1066,8 +1086,6 @@ L<http://rt.cpan.org>.
 
 Andy Armstrong C<< <andy@hexten.net> >>
 
-Hans Dieter Pearcey C<< <hdp@cpan.org> >>
-
 =head1 LICENCE AND COPYRIGHT
 
 Copyright (c) 2007, Andy Armstrong C<< <andy@hexten.net> >>. All rights reserved.
